# Python-API-Wrapper

This is a simple api wrapper written in python for the Minecraft Server, bedwarspractice.club. It is part of the Voxyl Network.
The wrapper supports general player info, guild info, and leaderboard info. More data support will be added soon